==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/HeaderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
/**
 * @hidden
 */
export let HeaderDescriptionMetadata = /*@__PURE__*/ (() => {
    class HeaderDescriptionMetadata extends Base {
        static b(a) {
            if (HeaderDescriptionMetadata.a == null) {
                HeaderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                HeaderDescriptionMetadata.c(HeaderDescriptionMetadata.a);
            }
            if (a.j(HeaderDescriptionMetadata.a)) {
                return;
            }
            a.y(HeaderDescriptionMetadata.a);
        }
        static c(a) {
            DefinitionBaseDescriptionMetadata.c(a);
            a.item("SortIndicatorColor", "Brush");
            a.item("ActualSortIndicatorColor", "Brush");
            a.item("SortIndicatorStyle", "ExportedType:string:SortIndicatorStyle");
            a.item("SortIndicatorStyle@names", "Default;FadingUpDownArrows;FadingSimpleUpDownArrows;Unset");
            a.item("ActualSortIndicatorStyle", "ExportedType:string:SortIndicatorStyle");
            a.item("ActualSortIndicatorStyle@names", "Default;FadingUpDownArrows;FadingSimpleUpDownArrows;Unset");
            a.item("PaddingLeft", "Number:int");
            a.item("PaddingTop", "Number:int");
            a.item("PaddingRight", "Number:int");
            a.item("PaddingBottom", "Number:int");
        }
        static d(a) {
            HeaderDescriptionMetadata.b(a);
            a.z("Header", HeaderDescriptionMetadata.a);
        }
    }
    HeaderDescriptionMetadata.$t = /*@__PURE__*/ markType(HeaderDescriptionMetadata, 'HeaderDescriptionMetadata');
    HeaderDescriptionMetadata.a = null;
    return HeaderDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/HeaderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
/**
 * @hidden
 */
export let HeaderDescriptionMetadata = /*@__PURE__*/ (() => {
    class HeaderDescriptionMetadata extends Base {
        static b(a) {
            if (HeaderDescriptionMetadata.a == null) {
                HeaderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                HeaderDescriptionMetadata.c(HeaderDescriptionMetadata.a);
            }
            if (a.k(HeaderDescriptionMetadata.a)) {
                return;
            }
            a.aa(HeaderDescriptionMetadata.a);
        }
        static c(a) {
            DefinitionBaseDescriptionMetadata.c(a);
            a.item("SortIndicatorColor", "Brush");
            a.item("ActualSortIndicatorColor", "Brush");
            a.item("SortIndicatorStyle", "ExportedType:string:SortIndicatorStyle");
            a.item("SortIndicatorStyle@names", "Default;FadingUpDownArrows;FadingSimpleUpDownArrows;Unset");
            a.item("ActualSortIndicatorStyle", "ExportedType:string:SortIndicatorStyle");
            a.item("ActualSortIndicatorStyle@names", "Default;FadingUpDownArrows;FadingSimpleUpDownArrows;Unset");
            a.item("PaddingLeft", "Number:int");
            a.item("PaddingTop", "Number:int");
            a.item("PaddingRight", "Number:int");
            a.item("PaddingBottom", "Number:int");
        }
        static d(a) {
            HeaderDescriptionMetadata.b(a);
            a.ab("Header", HeaderDescriptionMetadata.a);
        }
    }
    HeaderDescriptionMetadata.$t = /*@__PURE__*/ markType(HeaderDescriptionMetadata, 'HeaderDescriptionMetadata');
    HeaderDescriptionMetadata.a = null;
    return HeaderDescriptionMetadata;
})();
